@@ -531,10 +531,7 @@ HardwareTransformerInlineFormset = inlineformset_factory(DataTransformer, Hardwa
 HardwareStatsTransformerInlineFormset = inlineformset_factory(DataTransformer, HardwareStatsDataTransformer, extra=1,
                                                               form=HardwareStatsTransformerForm, can_delete_extra=True)
 
-dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
-                                                                     fk_name='parent',
-                                                                     can_delete_extra=True
-                                                                     )
+
 from django.utils.safestring import mark_safe
 
 
@@ -572,7 +569,6 @@ class DataTransform(forms.ModelForm):
                     initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id': str(uuid.uuid4())}]
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
-                self.nested_data_transformer_form.form = self
             else:
 
                 self.nested_data_transformer_form = dataTransformerInlineFormset(
@@ -581,7 +577,6 @@ class DataTransform(forms.ModelForm):
                     files=self.files if self.is_bound else None
                 )
                 self.nested_data_transformer_form.extra = 0
-                self.nested_data_transformer_form.form = self
 
         except Exception as e:
             print(str(e))
@@ -591,7 +586,6 @@ class DataTransform(forms.ModelForm):
                 files=self.files if self.is_bound else None
             )
             self.nested_data_transformer_form.extra = 0
-            self.nested_data_transformer_form.form = self
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
@@ -683,7 +677,11 @@ class DataTransform(forms.ModelForm):
 
 
 # DataTransformerFormset = form_factory(DataTransformer,formset=DataTransformerForm)
-
+dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                     fk_name='parent',
+                                                                     can_delete_extra=True,
+                                                                     form=DataTransform
+                                                                     )
 
 class DataTransformRoot(forms.ModelForm):
     id = forms.CharField(required=False,
@@ -711,7 +709,6 @@ class DataTransformRoot(forms.ModelForm):
                     initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id': str(uuid.uuid4())}]
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
-                self.nested_data_transformer_form.form = self
 
             else:
 
@@ -721,7 +718,6 @@ class DataTransformRoot(forms.ModelForm):
                     files=self.files if self.is_bound else None
                 )
                 self.nested_data_transformer_form.extra = 0
-                self.nested_data_transformer_form.form = self
         except Exception as e:
             print(str(e))
 
